@@ -4,12 +4,11 @@ dist.plot<- function(object,
                      stratum.index = NULL,
                      match.index   = NULL,
                      plot.type     = 1,
-                     compare       = FALSE,  
-
+                     compare       = FALSE,
                      cat.levels    = 10,
-                     plot.levels   = 5,              
+                     plot.levels   = 5,
                      label.match   = NULL,
-                     label.stratum = c("Stratum","Orginal"),
+                     label.stratum = c("Stratum","Original"),
                      with.legend  = TRUE,                
                      legend.title = NULL,
                      legend.cex   = 0.9,              
