@@ -60,7 +60,7 @@ ps.balance.data.frame <- function(object,
 
         A <- find.strata(data    = data,
                          strata  = match.index,
-                         matched = TRUE)
+                         match   = TRUE)
         
         match.index        <- A[[1]]
         name.match.index   <- A[[2]]
