@@ -5,7 +5,7 @@ summary.stratified.data.frame <- function(object,
   df <-
     data.frame(cbind(object$intervals,
                      as.numeric(table(object$stratum.index)),
-                     round(as.numeric(table(object$stratum.index))/dim(object$data)[1],3)*100))
+                     round(as.numeric(table(object$stratum.index))/dim(object$data)[1],3)))
 
   colnames(df) <- c("  Strata bounds","    n","    n (per cent)")
 
